Module: Sequel::MySQL::Dataset::CallableStatementMethods
- Defined in:
- lib/sequel_core/adapters/mysql.rb
Overview
Methods to add to MySQL prepared statement calls without using a real database prepared statement and bound variables.
Instance Method Summary collapse
-
#subselect_sql(ds) ⇒ Object
Extend given dataset with this module so subselects inside subselects in prepared statements work.
Instance Method Details
#subselect_sql(ds) ⇒ Object
Extend given dataset with this module so subselects inside subselects in prepared statements work.
224 225 226 227 228 229 |
# File 'lib/sequel_core/adapters/mysql.rb', line 224 def subselect_sql(ds) ps = ds.to_prepared_statement(:select) ps.extend(CallableStatementMethods) ps.prepared_args = prepared_args ps.prepared_sql end |