Method: Sequel::SQL::StringExpression.like

Defined in:
lib/sequel_core/sql.rb

.like(l, *ces) ⇒ Object

Creates a SQL pattern match exprssion. left (l) is the SQL string we are matching against, and ces are the patterns we are matching. The match succeeds if any of the patterns match (SQL OR). Patterns can be given as strings or regular expressions. Strings will cause the SQL LIKE operator to be used, and should be supported by most databases. Regular expressions will probably only work on MySQL and PostgreSQL, and SQL regular expression syntax is not fully compatible with ruby regular expression syntax, so be careful if using regular expressions.

The pattern match will be case insensitive if the last argument is a hash with a key of :case_insensitive that is not false or nil. Also, if a case insensitive regular expression is used (//i), that particular pattern which will always be case insensitive.



755
756
757
758
759
760
761
762
# File 'lib/sequel_core/sql.rb', line 755

def self.like(l, *ces)
  case_insensitive = ces.extract_options![:case_insensitive]
  ces.collect! do |ce|
    op, expr = Regexp === ce ? [ce.casefold? || case_insensitive ? :'~*' : :~, ce.source] : [case_insensitive ? :ILIKE : :LIKE, ce]
    BooleanExpression.new(op, l, expr)
  end
  ces.length == 1 ? ces.at(0) : BooleanExpression.new(:OR, *ces)
end